@@ -1,12 +1,13 @@
-package Pod::Markdown;
-
-use 5.006;
+use 5.008;
 use strict;
 use warnings;
 
-our $VERSION = '0.02';
-
-use base qw(Pod::Parser);
+package Pod::Markdown;
+BEGIN {
+  $Pod::Markdown::VERSION = '1.103490';
+}
+# ABSTRACT: Convert POD to Markdown
+use parent qw(Pod::Parser);
 
 sub initialize {
     my $self = shift;
@@ -18,25 +19,23 @@ sub initialize {
 sub _private {
     my $self = shift;
     $self->{_MyParser} ||= {
-        Text      => [],     # final text
-        Indent    => 0,      # list indent levels counter
-        ListType  => '-',    # character on every item
-        searching => undef,  # what are we searching for? (title, author etc.)
-        Title     => undef,  # page title
-        Author    => undef,  # page author
+        Text      => [],       # final text
+        Indent    => 0,        # list indent levels counter
+        ListType  => '-',      # character on every item
+        searching => undef,    # what are we searching for? (title, author etc.)
+        Title     => undef,    # page title
+        Author    => undef,    # page author
     };
 }
 
 sub as_markdown {
     my ($parser, %args) = @_;
-    my $data   = $parser->_private;
-    my $lines  = $data->{Text};
-
+    my $data  = $parser->_private;
+    my $lines = $data->{Text};
     my @header;
     if ($args{with_meta}) {
         @header = $parser->_build_markdown_head;
     }
-
     join("\n" x 2, @header, @{$lines});
 }
 
@@ -75,8 +74,7 @@ sub _indent_text {
 }
 
 sub _clean_text {
-    my $parser  = shift;
-    my $text    = shift;
+    my $text    = $_[1];
     my @trimmed = grep { $_; } split(/\n/, $text);
     return wantarray ? @trimmed : join("\n", @trimmed);
 }
@@ -92,8 +90,10 @@ sub command {
     if ($command =~ m{head(\d)}xms) {
         my $level = $1;
 
+        $paragraph = $parser->interpolate($paragraph, $line_num);
+
         # the headers never are indented
-        $parser->_save(sprintf '%s %s', '#' x $level, $paragraph);
+        $parser->_save($parser->format_header($level, $paragraph));
         if ($level == 1) {
             if ($paragraph =~ m{NAME}xmsi) {
                 $data->{searching} = 'title';
@@ -126,7 +126,7 @@ sub command {
 }
 
 sub verbatim {
-    my ($parser, $paragraph, $line_num) = @_;
+    my ($parser, $paragraph) = @_;
     $parser->_save($paragraph);
 }
 
@@ -153,8 +153,7 @@ sub textblock {
 }
 
 sub interior_sequence {
-    my ($parser, $seq_command, $seq_argument, $pod_seq) = @_;
-    my $data       = $parser->_private;
+    my ($seq_command, $seq_argument, $pod_seq) = @_[1..3];
     my %interiors = (
         'I' => sub { return '_' . $_[1] . '_' },      # italic
         'B' => sub { return '__' . $_[1] . '__' },    # bold
@@ -162,7 +161,7 @@ sub interior_sequence {
         'F' => sub { return '`' . $_[1] . '`' },      # system path
         'S' => sub { return '`' . $_[1] . '`' },      # code
         'E' => sub {
-            my ($seq, $charname) = @_;
+            my $charname = $_[1];
             return '<' if $charname eq 'lt';
             return '>' if $charname eq 'gt';
             return '|' if $charname eq 'verbar';
@@ -180,26 +179,45 @@ sub interior_sequence {
 }
 
 sub _resolv_link {
-    my ($cmd, $arg, $pod_seq) = @_;
-    if ($arg =~ m{^http|ftp}xms) {
+    my ($cmd, $arg) = @_;
+    my $text = $arg =~ s"^(.+?)\|"" ? $1 : '';
 
-        # direct link to a URL
-        return sprintf '<%s>', $arg;
-    } elsif ($arg =~ m{^(\w+(::\w+)*)$}) {
-        return "[$1](http://search.cpan.org/search?mode=module&query=$1)"
+    if ($arg =~ m{^http|ftp}xms) { # direct link to a URL
+        $text ||= $arg;
+        return sprintf '[%s](%s)', $text, $arg;
+    } elsif ($arg =~ m{^/(.*)$}) {
+        $text ||= $1;
+        $text = $1;
+        return "[$text](\#pod_$1)";
+    } elsif ($arg =~ m{^(\w+(?:::\w+)*)$}) {
+        $text ||= $1;
+        return "[$text](http://search.cpan.org/perldoc?$1)";
     } else {
         return sprintf '%s<%s>', $cmd, $arg;
     }
 }
 
+sub format_header {
+    my ($level, $paragraph) = @_[1,2];
+    sprintf '%s %s', '#' x $level, $paragraph;
+}
+
 1;
 
+
 __END__
+=pod
+
+=for stopwords textblock
 
 =head1 NAME
 
 Pod::Markdown - Convert POD to Markdown
 
+=head1 VERSION
+
+version 1.103490
+
 =head1 SYNOPSIS
 
     my $parser = Pod::Markdown->new;
@@ -212,80 +230,84 @@ This module subclasses L<Pod::Parser> and converts POD to Markdown.
 
 =head1 METHODS
 
-=over 4
-
-=item C<initialize>
+=head2 initialize
 
 Initializes a newly constructed object.
 
-=item C<as_markdown>
+=head2 as_markdown
 
 Returns the parsed POD as Markdown. Takes named arguments. If the C<with_meta>
 argument is given a positive value, meta tags are generated as well.
 
-=item C<command>
+=head2 command
 
 Handles POD command paragraphs, denoted by a line beginning with C<=>.
 
-=item C<verbatim>
+=head2 verbatim
 
 Handles verbatim text.
 
-=item C<textblock>
+=head2 textblock
 
 Handles normal blocks of POD.
 
-=item C<interior_sequence>
+=head2 interior_sequence
 
 Handles interior sequences in POD. An interior sequence is an embedded command
 within a block of text which appears as a command name - usually a single
 uppercase character - followed immediately by a string of text which is
 enclosed in angle brackets.
 
-=back
+=head2 format_header
 
-=head1 BUGS AND LIMITATIONS
-
-=over 4
-
-=item * Doesn't create pure Markdown texts. 
-
-=item * The links to manpages are incomplete.
-
-=back
-
-Please report any bugs or feature requests through the web interface at
-L<http://rt.cpan.org>.
+Formats a header according to the given level.
 
 =head1 INSTALLATION
 
 See perlmodinstall for information and options on installing Perl modules.
 
+=head1 BUGS AND LIMITATIONS
+
+No bugs have been reported.
+
+Please report any bugs or feature requests through the web interface at
+L<http://rt.cpan.org/Public/Dist/Display.html?Name=Pod-Markdown>.
+
 =head1 AVAILABILITY
 
 The latest version of this module is available from the Comprehensive Perl
 Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
-site near you. Or see L<http://search.cpan.org/dist/Pod-Markdown/>.
+site near you, or see L<http://search.cpan.org/dist/Pod-Markdown/>.
 
-The development version lives at L<http://github.com/hanekomu/pod-markdown/>.
-Instead of sending patches, please fork this project using the standard git
-and github infrastructure.
+The development version lives at L<http://github.com/hanekomu/Pod-Markdown.git>
+and may be cloned from L<git://github.com/hanekomu/Pod-Markdown.git>.
+Instead of sending patches, please fork this project using the standard
+git and github infrastructure.
 
 =head1 AUTHORS
 
-Marcel GrE<uuml>nauer, C<< <marcel@cpan.org> >>
+=over 4
 
-Victor Moral, C<< <victor@taquiones.net> >>
+=item *
+
+Marcel Gruenauer <marcel@cpan.org>
+
+=item *
+
+Victor Moral <victor@taquiones.net>
+
+=item *
+
+Ryan C. Thompson
+
+=back
 
 =head1 COPYRIGHT AND LICENSE
 
-Copyright 2009 by Marcel GrE<uuml>nauer
+This software is copyright (c) 2004 by Marcel Gruenauer.
 
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 SEE ALSO
-
-This module is strongly based on C<pod2mdwn> from L<Module::Build::IkiWiki>.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
